package org.apache.geronimo.ejemplos.dbtester.web;

import java.io.IOException;
import java.sql.SQLException;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.geronimo.ejemplos.dbtester.beans.DBManagerBean;

/**
 * Obtiene el contenido de una tabla de una Base de Datos y le dirige a la capa
 * de presentacin.
 * 
 * @author Adaptacin a EclipseWTP: Waldo Ramrez Montao
 */
public class ContentTableServlet extends HttpServlet {
    /**
     * serialVersionUID inicial.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Invoca al mtodo privado <b>getContent</b>, propio de esta misma clase.
     * 
     * @param request
     * @param response
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        getContent(request, response);
    }

    /**
     * Invoca al mtodo privado <b>doGet</b>, propio de esta misma clase.
     * 
     * @param request
     * @param response
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        doGet(request, response);
    }

    /**
     * Intenta obtener el contenido de una tabla de una base de datos, mediante
     * la clase {@link DBManagerBean}, proporcionndole el nombre de su pool,
     * el nombre del esquema y el nombre de la tabla.
     * 
     * @param request
     * @param response
     * @throws ServletException
     * @throws IOException
     */
    private void getContent(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException {
        String poolName = request.getParameter("poolName");
        String schemaName = request.getParameter("schemaName");
        String tableName = request.getParameter("tableName");
        String path = "/jsp/error_comun.jsp";

        try {
            DBManagerBean dbManager = (DBManagerBean) request.getSession()
                    .getAttribute("dbManager");
            List tableContent = dbManager.getTableContents(poolName,
                    schemaName, tableName);
            request.setAttribute("poolName", poolName);
            request.setAttribute("tableName", tableName);
            request.setAttribute("tableContent", tableContent);
            path = "/jsp/contenido_de_tabla.jsp";
        } catch (SQLException e) {
            e.printStackTrace();
            request.setAttribute("error", e);
        }
        request.setAttribute("poolName", poolName);
        getServletContext().getRequestDispatcher(path).forward(request,
                response);
    }

}
