package org.apache.geronimo.ejemplos.dbtester.web;

import java.io.IOException;
import java.sql.SQLException;
import java.util.Map;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.geronimo.ejemplos.dbtester.beans.DBManagerBean;

/**
 * Obtiene la lista de esquemas y tablas asociadas a una pool de conexiones a
 * BD.
 * 
 * @author Adaptacin a EclipseWTP: Waldo Ramrez Montao
 */
public class ListTablesServlet extends HttpServlet {
    /**
     * serialVersionUID inicial
     */
    private static final long serialVersionUID = 1L;

    /**
     * Invoca al mtodo privado <b>listTables</b>, propio de esta misma clase.
     * 
     * @param request
     * @param response
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        listTables(request, response);
    }

    /**
     * Invoca al mtodo privado <b>doGet</b>, propio de esta misma clase.
     * 
     * @param request
     * @param response
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        doGet(request, response);
    }

    /**
     * Intenta obtener la lista de tablas de una base de datos, mediante la
     * clase {@link DBManagerBean}, proporcionndole el nombre de su pool de
     * conexiones.
     * 
     * @param request
     * @param response
     * @throws ServletException
     * @throws IOException
     */
    private void listTables(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException {
        String poolName = request.getParameter("poolname");
        String path = "/jsp/error_comun.jsp";

        try {
            DBManagerBean dbManager = (DBManagerBean) request.getSession()
                    .getAttribute("dbManager");
            Map tableMap = dbManager.getTableList(poolName);
            request.setAttribute("tableMap", tableMap);
            path = "/jsp/lista_de_tablas.jsp";
        } catch (SQLException e) {
            e.printStackTrace();
            request.setAttribute("error", e);
        }
        request.setAttribute("poolName", poolName);
        getServletContext().getRequestDispatcher(path).forward(request,
                response);
    }

}
